@@ -13,11 +13,12 @@ from .types import *
 __title__ = 'Savify'
 __author__ = """Laurence Rawlings"""
 __email__ = 'contact@laurencerawlings.com'
-__version__ = '2.0.11'
+__version__ = '2.0.12'
 __license__ = 'MIT'
 __docformat__ = 'restructuredtext en'
 
-__all__ = ['savify', 'types']
+__all__ = ['savify', 'types', 'utils']
+
 
 def cli():
     from .cli import main
